<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=he
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_statistiques' => 'מחק סטטיסטיקות', # MODIF

	// I
	'icone_evolution_visites' => 'התפתחות ביקורים<br />@visites@ ביקורים',
	'icone_repartition_actuelle' => 'הראה תפוצה ממשית',
	'icone_repartition_visites' => 'חלוקת ביקורים',
	'icone_statistiques_visites' => 'סטטיסטיקת ביקורים',
	'info_affichier_visites_articles_plus_visites' => 'הצג ביקורים ל <b>the most visited articles since the beginning:</b>',
	'info_comment_lire_tableau' => 'איך לקרוא את הגרף הזה',
	'info_forum_statistiques' => 'סטטיסטיקות מבקרים',
	'info_popularite_2' => ':פופולריות האתר',
	'info_popularite_3' => 'פופולריות: @popularite@; :ביקורים @visites@',
	'info_popularite_5' => ':פופולריות',
	'info_visites' => 'ביקורים:',
	'info_zoom' => 'זום',
	'item_gerer_statistiques' => 'Gérer les statistiques', # MODIF

	// O
	'onglet_origine_visites' => 'מקור הביקורים',
	'onglet_repartition_debut' => 'מהתחלה',
	'onglet_repartition_lang' => 'התפלגות לפי השפה',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'titre_liens_entrants' => 'קישורים נכנסים',
];
